==> csa-1.0.0.crate: csa-1.0.0/CHANGELOG.md <==
<a name="unreleased"></a>
## [Unreleased]


<a name="1.0.0"></a>
## [1.0.0] - 2021-12-27
### Chore
- upgrade checkout action to v2 ([#13](https://github.com/nozaq/shogi-rs/issues/13))
- rename `master` branch to `main` ([#11](https://github.com/nozaq/shogi-rs/issues/11))


<a name="0.6.1"></a>
## [0.6.1] - 2021-08-15
### Refactor
- upgrade dependencies ([#10](https://github.com/nozaq/shogi-rs/issues/10))


<a name="0.6.0"></a>
## [0.6.0] - 2020-11-14
### Chore
- use tarpaulin to measure coverage

### Fix
- clippy warnings


<a name="0.5.0"></a>
## [0.5.0] - 2020-01-02

<a name="0.5,0"></a>
## [0.5,0] - 2020-01-02
### Feat
- upgrade to nom5
- upgrade to nom4


<a name="0.4.0"></a>
## [0.4.0] - 2020-01-01
### Chore
- use Github Actions
- use git-chglog to generate CHANGELOG

### Refactor
- cargo clippy
- cargo fmt


<a name="0.3.0"></a>
## [0.3.0] - 2019-01-27
### Fix
- add Cargo.toml

### Refactor
- migrate to 2018 edition


<a name="0.2.0"></a>
## [0.2.0] - 2017-06-24
### Chore
- remove redundant builds


<a name="0.1"></a>
## 0.1 - 2017-06-13

[Unreleased]: https://github.com/nozaq/shogi-rs/compare/1.0.0...HEAD
[1.0.0]: https://github.com/nozaq/shogi-rs/compare/0.6.1...1.0.0
[0.6.1]: https://github.com/nozaq/shogi-rs/compare/0.6.0...0.6.1
[0.6.0]: https://github.com/nozaq/shogi-rs/compare/0.5.0...0.6.0
[0.5.0]: https://github.com/nozaq/shogi-rs/compare/0.5,0...0.5.0
[0.5,0]: https://github.com/nozaq/shogi-rs/compare/0.4.0...0.5,0
[0.4.0]: https://github.com/nozaq/shogi-rs/compare/0.3.0...0.4.0
[0.3.0]: https://github.com/nozaq/shogi-rs/compare/0.2.0...0.3.0
[0.2.0]: https://github.com/nozaq/shogi-rs/compare/0.1...0.2.0

==> csa-1.0.1.crate: csa-1.0.1/CHANGELOG.md <==
<a name="unreleased"></a>
## [Unreleased]


<a name="1.0.1"></a>
## [1.0.1] - 2022-03-16
### Fix
- update parser for move records with comments ([#18](https://github.com/nozaq/shogi-rs/issues/18))


<a name="1.0.0"></a>
## [1.0.0] - 2021-12-27
### Chore
- upgrade checkout action to v2 ([#13](https://github.com/nozaq/shogi-rs/issues/13))
- rename `master` branch to `main` ([#11](https://github.com/nozaq/shogi-rs/issues/11))


<a name="0.6.1"></a>
## [0.6.1] - 2021-08-15
### Refactor
- upgrade dependencies ([#10](https://github.com/nozaq/shogi-rs/issues/10))


<a name="0.6.0"></a>
## [0.6.0] - 2020-11-14
### Chore
- use tarpaulin to measure coverage

### Fix
- clippy warnings


<a name="0.5.0"></a>
## [0.5.0] - 2020-01-02

<a name="0.5,0"></a>
## [0.5,0] - 2020-01-02
### Feat
- upgrade to nom5
- upgrade to nom4


<a name="0.4.0"></a>
## [0.4.0] - 2020-01-01
### Chore
- use Github Actions
- use git-chglog to generate CHANGELOG

### Refactor
- cargo clippy
- cargo fmt


<a name="0.3.0"></a>
## [0.3.0] - 2019-01-27
### Fix
- add Cargo.toml

### Refactor
- migrate to 2018 edition


<a name="0.2.0"></a>
## [0.2.0] - 2017-06-24
### Chore
- remove redundant builds


<a name="0.1"></a>
## 0.1 - 2017-06-13

[Unreleased]: https://github.com/nozaq/shogi-rs/compare/1.0.1...HEAD
[1.0.1]: https://github.com/nozaq/shogi-rs/compare/1.0.0...1.0.1
[1.0.0]: https://github.com/nozaq/shogi-rs/compare/0.6.1...1.0.0
[0.6.1]: https://github.com/nozaq/shogi-rs/compare/0.6.0...0.6.1
[0.6.0]: https://github.com/nozaq/shogi-rs/compare/0.5.0...0.6.0
[0.5.0]: https://github.com/nozaq/shogi-rs/compare/0.5,0...0.5.0
[0.5,0]: https://github.com/nozaq/shogi-rs/compare/0.4.0...0.5,0
[0.4.0]: https://github.com/nozaq/shogi-rs/compare/0.3.0...0.4.0
[0.3.0]: https://github.com/nozaq/shogi-rs/compare/0.2.0...0.3.0
[0.2.0]: https://github.com/nozaq/shogi-rs/compare/0.1...0.2.0
